@@ -9,7 +9,7 @@ use Error::Pure qw(err);
 use Mo::utils 0.06 qw(check_bool check_required);
 use Mo::utils::Hash qw(check_hash);
 
-our $VERSION = 0.08;
+our $VERSION = 0.09;
 
 # Constructor.
 sub new {
@@ -474,7 +474,7 @@ L<http://skim.cz>
 
 =head1 LICENSE AND COPYRIGHT
 
-© 2025 Michal Josef Špaček
+© 2025-2026 Michal Josef Špaček
 
 BSD 2-Clause License
 
@@ -487,6 +487,6 @@ the Czech Republic (DKRVO 2024–2028), Area 11: Linked Open Data.
 
 =head1 VERSION
 
-0.08
+0.09
 
 =cut
